Crate dyn_fmt

source ·
Static format macroDynamic analog
format!format
format_args!Arguments::new
write!dyn_write!

Feature flags

  • std (enabled by default) — disable to make the library #![no_std].

Macros

  • Writes formatted data into a buffer. A runtime analog of write! macro. In contrast with the macro format string have not be a string literal.

Structs

  • This structure represents a format string combined with its arguments. In contrast with fmt::Arguments this structure can be easily and safely created at runtime.

Traits

  • Extends strings with the format method, which is a runtime analog of the format! macro. Unavailable in no_std environment.