| Static format macro | Dynamic analog |
|---|---|
format! | format |
format_args! | Arguments::new |
write! | dyn_write! |
Feature flags
std(enabled by default) — disable to make the library#![no_std].
Macros
- Writes formatted data into a buffer. A runtime analog of
write!macro. In contrast with the macro format string have not be a string literal.
Structs
- This structure represents a format string combined with its arguments. In contrast with
fmt::Argumentsthis structure can be easily and safely created at runtime.
Traits
- Extends strings with the
formatmethod, which is a runtime analog of theformat!macro. Unavailable inno_stdenvironment.